require 'test_helper'

class OxenMessageTest < ActiveSupport::TestCase
  test "truth" do
    assert_kind_of Module, OxenMessage
  end

  test "message should have more headers" do
    msg = Message.create subject: "test"
    headers = [ MessageHeader.create( message: msg, name: "some label"), MessageHeader.create( message: msg, name: "some other label") ]
    msg = Message.last
    assert_equal 2,msg.message_headers.count
  end

  test "message should add named headers via keywords" do
    msg = Message.create from: "walther@alco.dk", subject: "test", cc: "bo@alco.dk", bcc: "kirstinehd@gmail.com"
    msg = Message.last
    assert_equal 3,msg.message_headers.count
    msg.cc = "mads@mikkelsen.dk,olebentsb@lloncirkus.fest"
    msg.save
    msg = Message.last
    assert_equal 3,msg.message_headers.count
    assert_equal "mads@mikkelsen.dk,olebentsb@lloncirkus.fest",msg.cc
  end

  test "message should have more attachments" do
    msg = Message.create subject: "test"
    fil1 = File.join Rails.root, '..',"attachment_1"
    fil2 = File.join Rails.root, '..',"support/attachment_2"
    attachments = [ MessageAttachment.create( message: msg, file: fil1), MessageAttachment.create( message: msg, file: fil2) ]
    msg = Message.last
    assert_equal 2,msg.message_attachments.count
  end


  test "message header should understand email address notation" do
    msg = Message.create subject: "test", bcc: "Walther Diechmann <walther@alco.dk>, mikkel@mus.com"
    msg = Message.last
    assert_equal 1,msg.message_headers.count
  end


end
